Constants class abstract

Core constants used throughout the Clonify CLI tool.

This class provides static constants and utility methods for accessing file paths, configuration templates, and tool metadata.

Constructors

Constants()

Properties

hashCode int
The hash code for this object.
no setterinherited
majorTaskDoneLine String
final
minorTaskDoneLine String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

aabPath String
The standard path for the Android App Bundle (AAB) file.
getter/setter pair
clonifySettingsFilePath String
The relative path to the main Clonify settings file.
getter/setter pair

Static Methods

configFilePath(String clientId) → dynamic
Generates the path to a client's configuration file.
ipaPath(String packageName) String
Generates the expected path for the iOS IPA file.

Constants

androidAppDirPath → const String
androidAppLevelBuildGradleFilePath → const String
androidAppLevelKotlinBuildGradleFilePath → const String
androidDebugDirName → const String
androidDebugManifestFilePath → const String
androidJavaMainActivityTemplate → const String
androidKotlinMainActivityTemplate → const String
androidMainDirName → const String
androidMainDirPath → const String
androidMainManifestFilePath → const String
androidManifestFileName → const String
androidProfileDirName → const String
androidProfileManifestFilePath → const String
androidSrcDirPath → const String
appInfoFileName → const String
appNameKey → const String
buildGradleFileName → const String
bundleNameKey → const String
cMakeListsFileName → const String
configKey → const String
copyrightKey → const String
descriptionKey → const String
desktopBinaryNameTemplate → const String
executableKey → const String
flutterLauncherIconsPath → const String
The path to the flutter_launcher_icons.yaml configuration file.
flutterLauncherIconsYaml → const String
A template string for the flutter_launcher_icons.yaml configuration file.
flutterNativeSplashPath → const String
The path to the flutter_native_splash.yaml configuration file.
flutterNativeSplashYaml → const String
A template string for the flutter_native_splash.yaml configuration file.
indexHtmlFileName → const String
infoPlistFileName → const String
iosDirPath → const String
iosInfoPlistFilePath → const String
iosProjectDirPath → const String
iosProjectFilePath → const String
iosRunnerDirPath → const String
kotlinBuildGradleFileName → const String
languageKey → const String
linuxCMakeListsFilePath → const String
linuxDirPath → const String
linuxMyApplicationFilePath → const String
linuxRunnerDirPath → const String
linuxRunnerMyApplicationFilePath → const String
macOSAppInfoFilePath → const String
macOSConfigDirPath → const String
macOSDirPath → const String
macOSProjectDirPath → const String
macOSProjectFilePath → const String
macOSRunnerXCSchemeFilePath → const String
macOSXCSchemesDirPath → const String
mainCppFileName → const String
manifestJsonFileName → const String
myApplicationFileName → const String
organizationKey → const String
outputLength → const int
overrideOldPackageKey → const String
packageNameKey → const String
packageRenameConfigFileName → const String
projectFileName → const String
pubspecFileName → const String
pubspecFilePath → const String
The relative path to the project's pubspec.yaml file.
runnerFileName → const String
runnerXCSchemeFileName → const String
shortAppNameKey → const String
toolName → const String
The official name of the Clonify CLI tool.
version → const String
The current version of the Clonify CLI tool. Note: This is now read dynamically from pubspec.yaml via the --version flag.
webDirPath → const String
webIndexFilePath → const String
webManifestFilePath → const String
windowsCMakeListsFilePath → const String
windowsDirPath → const String
windowsMainCppFilePath → const String
windowsRunnerDirPath → const String
windowsRunnerFilePath → const String