flutterNativeSplashYaml constant

String const flutterNativeSplashYaml

A template string for the flutter_native_splash.yaml configuration file.

This template is used to generate the configuration for the flutter_native_splash package, which helps in creating native splash screens for Flutter applications.

Implementation

static const String flutterNativeSplashYaml = '''
flutter_native_splash:
color: "#FFFFFF"
image: ""
android_12:
  image:
web: false
ios_content_mode: scaleToFill
fullscreen: true
''';