ClonifyCommands enum

ClonifyCommands is an enum representing different commands for clonify.

Inheritance
Available extensions

Values

create → const ClonifyCommands
init → const ClonifyCommands
which → const ClonifyCommands
configure → const ClonifyCommands
build → const ClonifyCommands
clean → const ClonifyCommands
upload → const ClonifyCommands
list → const ClonifyCommands

Properties

aliases List<String>

Available on ClonifyCommands, provided by the ClonifyCommandExtension extension

no setter
description String

Available on ClonifyCommands, provided by the ClonifyCommandExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on ClonifyCommands, provided by the ClonifyCommandExtension extension

no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ClonifyCommands>
A constant List of the values in this enum, in order of their declaration.