toolDescription constant
String
const toolDescription
Implementation
static const String toolDescription =
'A CLI tool that helps you manage your flutter project clones.';
static const String toolDescription =
'A CLI tool that helps you manage your flutter project clones.';