fastlaneSettingsFilePath property
Path to the Fastlane settings file relative to project root.
Implementation
final String fastlaneSettingsFilePath;
Path to the Fastlane settings file relative to project root.
final String fastlaneSettingsFilePath;