updateAndroidInfo property
Whether to update the Android info rename, splash screen and launcher icon.
Implementation
final bool updateAndroidInfo;
Whether to update the Android info rename, splash screen and launcher icon.
final bool updateAndroidInfo;