ClonifySettingsKeys class

Constructors

ClonifySettingsKeys()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

companyName → const String
customFields → const String
defaultColor → const String
enabled → const String
fastlane → const String
firebase → const String
needsLauncherIcon → const String
needsSplashScreen → const String
settingsFile → const String
updateAndroidInfo → const String
updateIOSInfo → const String