utils/asset_manager library
Functions
-
createCloneAssetsDirectory(
String clientId, List< String> assets) → bool - Creates an assets directory for a new clone and copies default assets into it.
-
replaceAssets(
String clientId) → void - Replaces the assets in the main project's assets directory with assets from a specific clone.