configFilePath static method

dynamic configFilePath(
  1. String clientId
)

Generates the path to a client's configuration file.

This method constructs the full path to the config.json file for a specific client, located within the ./clonify/clones/ directory.

clientId The ID of the client for which to get the config file path.

Returns a String representing the full path to the client's config file.

Implementation

static configFilePath(String clientId) =>
    './clonify/clones/$clientId/config.json';