flutterLauncherIconsYaml constant
String
const flutterLauncherIconsYaml
A template string for the flutter_launcher_icons.yaml configuration file.
This template is used to generate the configuration for the flutter_launcher_icons
package, which helps in creating adaptive launcher icons for Android and iOS.
Implementation
static const String flutterLauncherIconsYaml = '''
dev_dependencies:
flutter_launcher_icons: "^0.13.1"
flutter_launcher_icons:
android: "launcher_icon"
ios: true
remove_alpha_ios: true
image_path: ""
adaptive_icon_background: "#ffffff"
adaptive_icon_foreground: ""
min_sdk_android: 21
''';