Messages class abstract
User-facing messages and error strings for the Clonify CLI tool.
This class provides static methods and constants for generating consistent, user-friendly messages throughout the application.
Constructors
- Messages()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- clientIdRequired ↔ String
-
getter/setter pair
- clientIdRequiredForBuilding ↔ String
-
getter/setter pair
- clonifySettingsDoesNotContainAValidMap ↔ String
-
getter/setter pair
- clonifySettingsFileNotFound ↔ String
-
getter/setter pair
- pleaseVerifyBundleIdAndAppNameInXcodeProject ↔ String
-
getter/setter pair
Static Methods
-
configNotFoundForClientId(
String clientId) → String -
failedToReadOrParseClonifySettings(
Object error) → String -
failedToReadOrParseConfigFile(
String configFilePath, Object e) → String -
failedToReadOrParsePubspecFile(
Object e) → String -
failedToUploadClone(
String clientId, Object error) → String -
fieldHasInvalidType(
String field, Type runtimeType, Type? expectedType) → String -
missingRequiredField(
String field) → String -
useLastClientIdMessage(
String lastClientId) → String
Constants
- toolDescription → const String